forester
~~~~~~~~

This will be my collection of scripts for the linux shell. Currently I
am onboarding them one by one. So come back in a couple of weeks.

.. image:: https://codecov.io/gh/chr1st1ank/forester/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/chr1st1ank/forester


Features
========
* Summarize the size and latest changes of folders in a directory tree
* List how much space the subfolders in a directory tree take when considering hardlinks between them


Usage
=====


Installation
============
.. code-block:: sh

    pip install forester


Licence
=======


Contributing
============
Interested in particular changes? Found a bug?
Please read `CONTRIBUTING.md <https://github.com/chr1st1ank/forester/CONTRIBUTING.md>`__ for instructions on how to participate.


Licence
=======

The code in this repository is made available under the MIT license.
Feel free to use, change and distribute it.


